#!/usr/bin/env node --no-warnings
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_fs_1 = require("node:fs");
const node_child_process_1 = require("node:child_process");
const prompts_1 = require("@inquirer/prompts");
const fuzzysort_1 = __importDefault(require("fuzzysort"));
const utils_1 = require("./lib/utils");
if ((0, node_fs_1.existsSync)("package.json") === false) {
    (0, utils_1.noFileError)();
}
(0, node_fs_1.readFile)("package.json", "utf8", (err, data) => __awaiter(void 0, void 0, void 0, function* () {
    if (err)
        throw err;
    const pkg = JSON.parse(data);
    if (pkg.scripts === undefined)
        (0, utils_1.noScriptsError)();
    const scriptNames = Object.keys(pkg.scripts);
    try {
        const answer = yield (0, prompts_1.search)({
            message: "Which command would you like to run?",
            source: (input) => __awaiter(void 0, void 0, void 0, function* () {
                if (!input) {
                    return scriptNames.map(script => ({
                        name: script,
                        value: script
                    }));
                }
                const results = fuzzysort_1.default.go(input, scriptNames);
                return results.map(result => ({
                    name: result.target,
                    value: result.target,
                    description: `Match score ${result.score.toFixed(3)}`
                }));
            })
        });
        (0, node_child_process_1.spawn)("bun", ["run", `${answer}`], { stdio: "inherit" });
    }
    catch (error) {
        if (error instanceof Error) {
            if (error.name === "ExitPromptError") {
                (0, utils_1.exitPromptError)();
                return;
            }
        }
        console.log(error);
    }
}));
